#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 summoner
version:              2.0.1.1
visibility:           public
id:                   summoner-2.0.1.1-FnEeYX6MX9y678KFHPp4c8
key:                  summoner-2.0.1.1-FnEeYX6MX9y678KFHPp4c8
license:              MPL-2.0
copyright:            2018-2020 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina, Dmitrii Kovanikov
stability:            stable
homepage:             https://github.com/kowainik/summoner
synopsis:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects.

description:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects.
    See [README.md](https://github.com/kowainik/summoner#-summoner) for details.

category:             CLI, CLI Tool, Development
abi:                  9b97e1811ddac7c2bcd6a9aab0055d66
exposed:              True
exposed-modules:
    Summoner Summoner.CLI Summoner.Config Summoner.CustomPrelude
    Summoner.Decision Summoner.Default Summoner.GhcVer Summoner.License
    Summoner.Mode Summoner.Project Summoner.Question Summoner.Settings
    Summoner.Source Summoner.Template Summoner.Template.Cabal
    Summoner.Template.Doc Summoner.Template.GitHub
    Summoner.Template.Haskell Summoner.Template.Script
    Summoner.Template.Stack Summoner.Text Summoner.Tree

hidden-modules:       Paths_summoner
import-dirs:          /usr/lib/ghc-8.10.5/site-local/summoner-2.0.1.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/summoner-2.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/summoner-2.0.1.1
hs-libraries:         HSsummoner-2.0.1.1-FnEeYX6MX9y678KFHPp4c8
depends:
    base-4.14.2.0 relude-0.7.0.0-CgGiQ6XK8YdC8DsVOJvn5Z
    aeson-1.5.6.0-CVfeYccFVpdCde0UrZZZdZ
    colourista-0.1.0.1-KcXyXznqdT1GDzaOFE3qYT containers-0.6.4.1
    directory-1.3.6.0 filepath-1.4.2.1
    generic-data-0.9.2.0-LD5LrJACrod6dz7pmdMEQh
    gitrev-1.3.1-IeAYO8QUG62LW4J3MUanQA
    neat-interpolation-0.5.1.2-JnP70tAK7gc9ekAYp3VaAX
    optparse-applicative-0.16.1.0-ARX6qDeExVWDKYrQ55nL8e
    process-1.6.9.0 shellmet-0.0.4.0-JNTUtCaGFEG9aj1JYTOPt9
    text-1.2.4.1 time-1.9.3 tomland-1.3.3.0-72QyqTYF7VP1FwOfDNVYcA
    validation-selective-0.1.0.1-HPBMKQJZbzhCAzNKlJ3xRq

haddock-interfaces:   /usr/share/doc/haskell-summoner/html/summoner.haddock
haddock-html:         /usr/share/doc/haskell-summoner/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

